==> libnetconf-0.9.1.tar.gz: libnetconf/doc/doxygen/html/d7/d62/notifications_8h.js <==
var notifications_8h =
[
    [ "NCNTF_STREAM_BASE", "d7/d62/notifications_8h.html#adab5cbd0f58cd86a8dc67bb66615d78a", null ],
    [ "NCNTF_STREAM_DEFAULT", "d7/d62/notifications_8h.html#a894f5136a973b19ccfc84c78712ec17b", null ],
    [ "NCNTF_EVENT", "da/d54/group__notifications.html#gadcf8c532762d57f7d9a5491e6abb9977", [
      [ "NCNTF_ERROR", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977abd5b82879a0ac7c45f8556154fb6286a", null ],
      [ "NCNTF_GENERIC", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977a1f1e3c2032baf2542b06052243bd42c9", null ],
      [ "NCNTF_REPLAY_COMPLETE", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977aa440351ba1c82a0dd9e5301a6d03c5ac", null ],
      [ "NCNTF_NTF_COMPLETE", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977a0a0d2e20f15e710f1da3dace9a55fc67", null ],
      [ "NCNTF_BASE_CFG_CHANGE", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977a9cf730f96784afdb8d783df8dacfab21", null ],
      [ "NCNTF_BASE_CPBLT_CHANGE", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977af6adea71e2edc918ae1f7ade6f11ca59", null ],
      [ "NCNTF_BASE_SESSION_START", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977a7e0ecf6ec462565f5bc9a1edfd7d4c6c", null ],
      [ "NCNTF_BASE_SESSION_END", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977a1c06188153af81757d0ba8aac0768550", null ],
      [ "NCNTF_BASE_CONFIRMED_COMMIT", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977a2048b9cca78f499a6f361e9eeb9fa3e5", null ]
    ] ],
    [ "NCNTF_EVENT_BY", "da/d54/group__notifications.html#ga1e9d948b3807d679482c737da720477d", [
      [ "NCNTF_EVENT_BY_SERVER", "da/d54/group__notifications.html#gga1e9d948b3807d679482c737da720477da378e4e13ce4d7f8e1ede2a876fbc30e0", null ],
      [ "NCNTF_EVENT_BY_USER", "da/d54/group__notifications.html#gga1e9d948b3807d679482c737da720477dab20423755c56c213cd2567b2bbf1f9c2", null ]
    ] ],
    [ "ncntf_dispatch_receive", "da/d54/group__notifications.html#ga82da94949fd2d901c3abb2c82882346c", null ],
    [ "ncntf_dispatch_send", "da/d54/group__notifications.html#ga9a085479245b4da6e20fd89892cc7bc1", null ],
    [ "ncntf_event_new", "da/d54/group__notifications.html#ga9641deaca934bcd7ff66ac3ae60fc722", null ],
    [ "ncntf_notif_create", "da/d54/group__notifications.html#ga226e6acf872c57ca4de3847718cfaafe", null ],
    [ "ncntf_notif_free", "da/d54/group__notifications.html#gabc56c72fca74236e9c96f694cf521b67", null ],
    [ "ncntf_notif_get_content", "da/d54/group__notifications.html#gadc78f4dd6440f4f1ac3ea12092946bd3", null ],
    [ "ncntf_notif_get_time", "da/d54/group__notifications.html#gae00135a2cb85cb2d74d7f0b8b355ab47", null ],
    [ "ncntf_notif_get_type", "da/d54/group__notifications.html#ga3f32038a98705a6dbb9d7038f67cbceb", null ],
    [ "ncntf_status", "da/d54/group__notifications.html#ga8c116b8aae2fe13811ebbfd3ca6f1a44", null ],
    [ "ncntf_stream_allow_events", "da/d54/group__notifications.html#ga05a14f949bbb781fd58a233b1d2fab33", null ],
    [ "ncntf_stream_info", "da/d54/group__notifications.html#gaff62ddbbd893faf50d3db3fa3b08c21f", null ],
    [ "ncntf_stream_isavailable", "da/d54/group__notifications.html#ga8958e791e810dd07b9121d78c870e8c5", null ],
    [ "ncntf_stream_iter_finish", "da/d54/group__notifications.html#ga1f45b88f42bd06a4518433f79c5999a3", null ],
    [ "ncntf_stream_iter_next", "da/d54/group__notifications.html#gae9e1a02911f865bbc0f2b4e702b82ed7", null ],
    [ "ncntf_stream_iter_start", "da/d54/group__notifications.html#ga999c0dc786381fe91f1158b76bcbdee9", null ],
    [ "ncntf_stream_list", "da/d54/group__notifications.html#ga1f8e55f0f292f0514e844e7293e2b6b4", null ],
    [ "ncntf_stream_new", "da/d54/group__notifications.html#ga30691c17b09e98c56d39c9ebfaba1ded", null ],
    [ "ncntf_subscription_check", "da/d54/group__notifications.html#gad1efe90aba028ffbb2b018b30f8e3a4b", null ]
];

==> libnetconf-0.10.0.tar.gz: libnetconf/doc/doxygen/html/d7/d62/notifications_8h.js <==
var notifications_8h =
[
    [ "NCNTF_STREAM_BASE", "d7/d62/notifications_8h.html#adab5cbd0f58cd86a8dc67bb66615d78a", null ],
    [ "NCNTF_STREAM_DEFAULT", "d7/d62/notifications_8h.html#a894f5136a973b19ccfc84c78712ec17b", null ],
    [ "NCNTF_EVENT", "da/d54/group__notifications.html#gadcf8c532762d57f7d9a5491e6abb9977", [
      [ "NCNTF_ERROR", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977abd5b82879a0ac7c45f8556154fb6286a", null ],
      [ "NCNTF_GENERIC", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977a1f1e3c2032baf2542b06052243bd42c9", null ],
      [ "NCNTF_REPLAY_COMPLETE", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977aa440351ba1c82a0dd9e5301a6d03c5ac", null ],
      [ "NCNTF_NTF_COMPLETE", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977a0a0d2e20f15e710f1da3dace9a55fc67", null ],
      [ "NCNTF_BASE_CFG_CHANGE", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977a9cf730f96784afdb8d783df8dacfab21", null ],
      [ "NCNTF_BASE_CPBLT_CHANGE", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977af6adea71e2edc918ae1f7ade6f11ca59", null ],
      [ "NCNTF_BASE_SESSION_START", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977a7e0ecf6ec462565f5bc9a1edfd7d4c6c", null ],
      [ "NCNTF_BASE_SESSION_END", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977a1c06188153af81757d0ba8aac0768550", null ],
      [ "NCNTF_BASE_CONFIRMED_COMMIT", "da/d54/group__notifications.html#ggadcf8c532762d57f7d9a5491e6abb9977a2048b9cca78f499a6f361e9eeb9fa3e5", null ]
    ] ],
    [ "NCNTF_EVENT_BY", "da/d54/group__notifications.html#ga1e9d948b3807d679482c737da720477d", [
      [ "NCNTF_EVENT_BY_SERVER", "da/d54/group__notifications.html#gga1e9d948b3807d679482c737da720477da378e4e13ce4d7f8e1ede2a876fbc30e0", null ],
      [ "NCNTF_EVENT_BY_USER", "da/d54/group__notifications.html#gga1e9d948b3807d679482c737da720477dab20423755c56c213cd2567b2bbf1f9c2", null ]
    ] ],
    [ "ncntf_dispatch_receive", "da/d54/group__notifications.html#ga82da94949fd2d901c3abb2c82882346c", null ],
    [ "ncntf_dispatch_send", "da/d54/group__notifications.html#ga9a085479245b4da6e20fd89892cc7bc1", null ],
    [ "ncntf_event_new", "da/d54/group__notifications.html#ga9641deaca934bcd7ff66ac3ae60fc722", null ],
    [ "ncntf_notif_create", "da/d54/group__notifications.html#ga226e6acf872c57ca4de3847718cfaafe", null ],
    [ "ncntf_notif_free", "da/d54/group__notifications.html#gabc56c72fca74236e9c96f694cf521b67", null ],
    [ "ncntf_notif_get_content", "da/d54/group__notifications.html#gadc78f4dd6440f4f1ac3ea12092946bd3", null ],
    [ "ncntf_notif_get_time", "da/d54/group__notifications.html#gae00135a2cb85cb2d74d7f0b8b355ab47", null ],
    [ "ncntf_notif_get_type", "da/d54/group__notifications.html#ga3f32038a98705a6dbb9d7038f67cbceb", null ],
    [ "ncntf_session_get_active_subscription", "da/d54/group__notifications.html#ga3c44d0f8b0ffe29050de73f2ac209a32", null ],
    [ "ncntf_status", "da/d54/group__notifications.html#ga8c116b8aae2fe13811ebbfd3ca6f1a44", null ],
    [ "ncntf_stream_allow_events", "da/d54/group__notifications.html#ga05a14f949bbb781fd58a233b1d2fab33", null ],
    [ "ncntf_stream_info", "da/d54/group__notifications.html#gaff62ddbbd893faf50d3db3fa3b08c21f", null ],
    [ "ncntf_stream_isavailable", "da/d54/group__notifications.html#ga8958e791e810dd07b9121d78c870e8c5", null ],
    [ "ncntf_stream_iter_finish", "da/d54/group__notifications.html#ga1f45b88f42bd06a4518433f79c5999a3", null ],
    [ "ncntf_stream_iter_next", "da/d54/group__notifications.html#gae9e1a02911f865bbc0f2b4e702b82ed7", null ],
    [ "ncntf_stream_iter_start", "da/d54/group__notifications.html#ga999c0dc786381fe91f1158b76bcbdee9", null ],
    [ "ncntf_stream_list", "da/d54/group__notifications.html#ga1f8e55f0f292f0514e844e7293e2b6b4", null ],
    [ "ncntf_stream_new", "da/d54/group__notifications.html#ga30691c17b09e98c56d39c9ebfaba1ded", null ],
    [ "ncntf_subscription_check", "da/d54/group__notifications.html#gad1efe90aba028ffbb2b018b30f8e3a4b", null ]
];
